Thread (68 messages) flat view 68 messages, 5 authors, 2025-05-21

Re: [PATCH v6 13/16] PCI/AER: Rename struct aer_stats to aer_report

From: Bjorn Helgaas <helgaas@kernel.org>
Date: 2025-05-20 21:25:31
Also in: linux-pci, lkml

On Mon, May 19, 2025 at 08:30:09PM -0700, Sathyanarayanan Kuppuswamy wrote:
On 5/19/25 2:35 PM, Bjorn Helgaas wrote:
quoted
From: Karolina Stolarek <redacted>

Update name to reflect the broader definition of structs/variables that are
stored (e.g. ratelimits). This is a preparatory patch for adding rate limit
support.

Link: https://lore.kernel.org/r/20250321015806.954866-6-pandoh@google.com (local)
Signed-off-by: Karolina Stolarek <redacted>
Signed-off-by: Bjorn Helgaas <bhelgaas@google.com>
---
Reviewed-by: Kuppuswamy Sathyanarayanan <sathyanarayanan.kuppuswamy@linux.intel.com>
quoted
  drivers/pci/pcie/aer.c | 50 +++++++++++++++++++++---------------------
  include/linux/pci.h    |  2 +-
  2 files changed, 26 insertions(+), 26 deletions(-)
diff --git a/drivers/pci/pcie/aer.c b/drivers/pci/pcie/aer.c
index 06a7dda20846..da62032bf024 100644
--- a/drivers/pci/pcie/aer.c
+++ b/drivers/pci/pcie/aer.c
@@ -54,11 +54,11 @@ struct aer_rpc {
  	DECLARE_KFIFO(aer_fifo, struct aer_err_source, AER_ERROR_SOURCES_MAX);
  };
-/* AER stats for the device */
-struct aer_stats {
+/* AER report for the device */
+struct aer_report {
For me aer_report also sounds like stats like struct. I prefer
aer_info, but it is up to you.
I tend to agree and can imagine a future where we might collect the
stats, ratelimits, and maybe aer_capability_regs into a per-device AER
structure.  "aer_info" seems like a decent generic name, so I did
s/\<aer_stats\>/aer_info/
Keyboard shortcuts
hback out one level
jnext message in thread
kprevious message in thread
ldrill in
Escclose help / fold thread tree
?toggle this help